==> pynetics-0.6.1.tar.gz: pynetics-0.6.1/pynetics/__init__.py <==
# ======================================================================
# pynetics: a simple yet powerful evolutionary computation library
# Copyright (C) 2020 Alberto Díaz-Álvarez
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
# THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# ======================================================================
"""Import core names of pynetics.

This library provides the means to create genetic algorithms in a simple
yet fast way. Specifically:
  1. A generic and modular algorithm to be composed by the different
  parts that build a whole algorithm.
  2. Simple algorithm implementations with some defaults implemented.
  3. Different generic operators (e.g. crossover or mutation) to work
  with different genotypes (e.g. binary list, real list).

The fastest way to work with this library is by importing this file
directly:

>>> import pynetics as pyn

TODO Organize in a way that this actually happens
"""
__version__ = '0.6.1'

==> pynetics-0.7.0.tar.gz: pynetics-0.7.0/pynetics/__init__.py <==
# ======================================================================
# pynetics: a simple yet powerful evolutionary computation library
# Copyright (C) 2020 Alberto Díaz-Álvarez
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
# THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# ======================================================================
"""Import core names of pynetics.

This library provides the means to create genetic algorithms in a simple
yet fast way. Specifically:

1. A generic and modular algorithm to be composed by the different parts
that build a whole algorithm.
2. Simple algorithm implementations with some defaults implemented.
3. Different generic operators (e.g. crossover or mutation) to work with
different genotypes (e.g. binary list, real list).

The fastest way to work with this library is by importing this file
directly:

>>> import pynetics as pyn

TODO Organize in a way that this actually happens
"""
__version__ = '0.7.0'
